//Donkey Punch Adventure - made by Drew Ferraro graveyardfilla@hotmail.com . released under the GPL
//see "COPYING.txt" for more info

#ifndef MAIN_H
#define MAIN_H

#ifdef WIN32
#pragma comment(lib, "SDL.lib")
#pragma comment(lib, "SDLmain.lib")
#pragma comment(lib, "SDL_image.lib")
#pragma comment(lib,"SDL_mixer.lib")
#pragma comment(lib,"sdl_ttf.lib")
#endif


#include <stdio.h>
#include <stdlib.h>
#include <iostream>
#include <istream>
#include <fstream> 
#include <string>
#include <sstream> //this is to convert an int (the score) to a string for drawing (used in Draw_Score())
#include <vector>
using namespace std;

#include "SDL.h"
#include "SDL_image.h"
#include "SDL_mixer.h"
#include "SDL_ttf.h"



#pragma comment(linker, "/subsystem:\"windows\" /entry:\"mainCRTStartup\"") 
//get rid of that ugly console window

enum Directions //directions the donkey-man and the enemy gloves can travel
{
	GO_UP,
	GO_DOWN,
	GO_LEFT,
	GO_RIGHT,
	STOP,
	NONE
};


enum Tile_Types
{
 OPEN_SPACE, //0
 DOOR,

 PLAYER,
 RED_ENEMY, 
 PURPLE_ENEMY,
 BLUE_ENEMY, //5
 YELLOW_ENEMY,

 WARP_INTERSECTIONS,  //intersections for enemy AI
 CHECK_GO_NORTH, 		//more intersection
 CHECK_GO_SOUTH,	  //more intersection
 CHECK_GO_WEST,//10
 CHECK_GO_EAST,
 
 OPEN_CK_NORTH,		//after the pacman eats the food that was on an intersection tile,
 OPEN_CK_SOUTH,		//we dont want the enemies to lose their AI, so we have them changed these
 OPEN_WARP,
 OPEN_CK_WEST,//15
 OPEN_CK_EAST,
 
 FOOD, 
 GLOWING_FOOD,	//tiles to open spaces, but STILL be intersections. there fore there is 2 types
 
 BOMB,//19

 //now const int walls[10] takes up 22-whatever
};		




enum Entity_Modes
{
	ACTIVE,
	STANDBY,
	E_DEAD,
	P_DEAD,
	SCARED
};

const int MAX_WALLS = 16;

const int WALLS[MAX_WALLS] = {20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35}; 
//array of walls, should be in Tile_Types  but enums cant be arrays


class data         //data is the struct which holds all of our images used in Init_Map and Draw_Backgrounds()
{
	public:

	data()
	{done = 0;}
	~data()
	{
		//free our surfaces on our way out
		SDL_FreeSurface(open_space);
	
		SDL_FreeSurface(dynomite);
		SDL_FreeSurface(boom);
		SDL_FreeSurface(boom2);	
	
		SDL_FreeSurface(door);
		SDL_FreeSurface(blank_sheet);
		
		for(int i = 0; i < 4; i++)
			SDL_FreeSurface(glow_food[i]);
		
		for(int j = 0; j < 5; j++)
			SDL_FreeSurface(ball[j]);
		
		for(int k = 0; k < MAX_WALLS; k++)
			SDL_FreeSurface(walls[k]);

		current_level = 0;
		food_count = 0;
	
	}

	SDL_Surface *walls[MAX_WALLS];
	
	SDL_Surface *screen;
	SDL_Surface *open_space;
	SDL_Surface *door;
	
	//bomb images 
	SDL_Surface *dynomite;
    SDL_Surface *boom;
    SDL_Surface *boom2;

	SDL_Surface *glow_food[4];
	SDL_Surface *ball[5];

	//this blank sheet is just a black rectangle... we slice it to draw over the score,time,etc at the top
	SDL_Surface *blank_sheet;

	int glow_counter;			//a counter used in draw_backgrounds to increment to the next frame of food

	int done;							//when this equals 0 the game ends

	int current_level;

	int food_count;
};

//extern data data;

const int GREY = 0;
const int WHITE = 1;
//these "enums" are used in loading in the grey and white sprite bases in Init_Entities
//and possibly other places. these had no home because the other sprite bases had names
//like RED_PLAYER etc which were conveniently allready enums in Tile_Types{}

void DrawIMG(SDL_Surface *img, int x, int y); //this draws the gloves and the ball

void DrawBG(SDL_Surface *img,int dx,int dy,int w,int h);

void Take_Input();

void Flip();

void Load_Level(); 

void Init_Map();//used in Messages::Game_Over


void Open(string MAP);

SDL_Surface* Load_Image(char *filename);

#endif 


